@@ -11,4 +11,9 @@ pub const NO_EOF_NEWLINE_MARKER: &str = "\\ No newline at end of file";
 pub const BOLD: &str = "\x1b[1m";
 pub const FAINT: &str = "\x1b[2m";
 
+pub const YELLOW: &str = "\x1b[33m";
+pub const GREEN: &str = "\x1b[32m";
+pub const CYAN: &str = "\x1b[36m";
+pub const RED: &str = "\x1b[31m";
+
 pub const NORMAL: &str = "\x1b[0m";
