@@ -20,14 +20,13 @@ use std::process::{Command, Stdio};
 use std::str;
 use std::{env, fs::File};
 
+mod commit_line;
 mod constants;
 mod line_collector;
 mod refiner;
 mod token_collector;
 mod tokenizer;
 
-// NOTE: Setting pager.log to riff makes "git log -p" output look nicer, but
-// just "git log" without "-p" look worse. Better not go there.
 const HELP_TEXT: &str = r#"
 Usage:
   diff ... | riff
@@ -39,6 +38,7 @@ Colors diff output, highlighting the changed parts of every line.
 Git integration:
     git config --global pager.diff riff
     git config --global pager.show riff
+    git config --global pager.log riff
     git config --global interactive.diffFilter riff
 
 Options:
